/**
  *  \file client/screens/shiptaskscreen.h
  *  \brief Ship Task Screen
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_SCREENS_SHIPTASKSCREEN_H
#define PCC_V2_CLIENT_SCREENS_SHIPTASKSCREEN_H

#include <memory>
#include "client/screens/taskscreen.h"
#include "int/if/shippred.h"
#include "game/coord.h"

/** Ship Auto Task Type. This operates as an object selection for a screen.
    It manages a predictor, which it keeps current all the time, for
    ship auto task screen tiles to use. */
class WShipAutoTaskSelection : public WAutoTaskObjectSelection {
    std::auto_ptr<IntShipPredictor> predictor;
 public:
    WShipAutoTaskSelection(GObjectSelection& base);
    IntExecutionContext* getTask(bool create);

    void onTaskChange();

    void insertWaypointCommand(const char* cmd, GPoint pt, bool setWarp, bool ignoreDuplicate);

    bool isPredictToEnd();
    void setPredictToEnd(bool value);

    bool isShowDistances();
    void setShowDistances(bool value);

    const IntShipPredictor* getPredictor() const;
};

void doShipAutoTaskScreen();

#endif
