/**
  *  \file client/widgets/histposlist.h
  *  \brief WHistoryShipPositionList widget
  *
  *  (c) 2001-2020 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_HISTPOSLIST_H
#define PCC_V2_CLIENT_WIDGETS_HISTPOSLIST_H

#include "game/ship.h"
#include "ui/listbox.h"

/** Display position list for a history ship. This displays a ship's
    previous positions and allows the user to choose a turn. It tries
    to achieve a uniform layout with the current turn always at the
    bottom of the list when possible.

    This widget's main occupation is as the working component in
    WHistoryShipPositionTile, but it can also be used standalone.

    Implementation note: like the GShip history, this stores a turn
    range as inverse half-open interval, i.e. (min_turn,max_turn]. To
    ensure that the current turn can stand at the bottom, this
    enforces a minimum size corresponding to the widget height, which
    may require a non-positive min_turn. */
class WHistoryShipPositionList : public UIListbox {
 public:
    WHistoryShipPositionList(int lines, int width);
    ~WHistoryShipPositionList();

    void setShip(const GShip* ship);
    int getTurn() const;
    void setTurn(int turn);

    // UIListbox:
    void drawPart(GfxCanvas& can, int from, int to);
    bool isAccessible(int pos);

 private:
    const GShip* ship;
    int min_turn;       /* oldest turn NOT shown */
    int max_turn;       /* newest turn shown */
};

#endif
